pub enum PitchInvariant {
TotalOrder,
AggregateIdentity,
}Expand description
A source invariant that no longer holds after a transform.
Variants
TotalOrder
The result is no longer one strict twelve-position row.
AggregateIdentity
The result no longer contains each pitch class exactly once.