pub struct AllIntervalMultiplicity {
pub interval: u8,
pub count: u8,
}Expand description
One duplicated adjacent directed interval together with its multiplicity.
Fields
interval: u8The directed interval value in semitones modulo twelve.
count: u8The number of times interval occurs in the row.