pub struct RowMatrixEdgeLabels { /* private fields */ }Expand description
Labels printed on the four edges of a row matrix.
Left-to-right rows are P forms and right-to-left rows are R forms. Top-to- bottom columns are I forms and bottom-to-top columns are RI forms.
Implementations
Sourceimpl RowMatrixEdgeLabels
impl RowMatrixEdgeLabels
Sourcepub const fn top(&self) -> &[RowLabel; 12]
pub const fn top(&self) -> &[RowLabel; 12]
Returns the I labels above the columns, ordered left to right.
Sourcepub const fn right(&self) -> &[RowLabel; 12]
pub const fn right(&self) -> &[RowLabel; 12]
Returns the R labels beside the rows, ordered top to bottom.